@@ -1,8 +1,7 @@
 use crate::server::*;
 use anyhow::Result;
-use netxclient::*;
+use netxclient::prelude::*;
 use std::cell::RefCell;
-use std::sync::Arc;
 
 #[build(TestController)]
 pub trait ITestController {
@@ -12,20 +11,16 @@ pub trait ITestController {
     async fn disconnect(&self) -> Result<()>;
 }
 
-type Client = Arc<Actor<NetXClient<DefaultSessionStore>>>;
-
 #[allow(dead_code)]
 pub struct TestController {
-    client: Client,
     server: Box<dyn IServer>,
     name: RefCell<String>,
 }
 
 impl TestController {
-    pub fn new(client: Client) -> TestController {
+    pub fn new(client: NetxClientArcDef) -> TestController {
         TestController {
-            server: impl_interface!(client=>IServer),
-            client,
+            server: impl_owned_interface!(client=>IServer),
             name: RefCell::new("".to_string()),
         }
     }
